/**
 * Eksempel p bruk av figurklassen ifb interface.
 * Klassene er implementasjonen som skjules for omverden.
 */
package figur;
abstract class Figur implements FigurInterface {
  /* Alle figurer kan beregne sitt eget areal */
  public abstract double beregnAreal();
}

/**
 * Kvadrat: Arealet er lik side * side
 */
class Kvadrat extends Figur {
  private final double side;

  public Kvadrat(int side) {
    this.side = side;
  }

  public double getSide() {
    return side;
  }

  public double beregnAreal() {
    return side * side;
  }
}

/**
 * Trekant: Arealet er lik 0,5 * grunnlinje * hyde
 */
class Trekant extends Figur {
  private final double grunnlinje;
  private final double hyde;

  public Trekant(double grunnlinje, double hyde) {
    this.grunnlinje = grunnlinje;
    this.hyde = hyde;
  }

  public double getGrunnlinje() {
    return grunnlinje;
  }

  public double getHyde() {
    return hyde;
  }

  public double beregnAreal() {
    return 0.5 * grunnlinje * hyde;
  }
}

/**
 * Sirkel: Arealet er lik pi * radius * radius
 */
class Sirkel extends Figur {
  private final double radius;

  public Sirkel(double radius) {
    this.radius = radius;
  }

  public double getRadius() {
    return radius;
  }

  public double beregnAreal() {
    return Math.PI * radius * radius ;
  }
}